@@ -24,9 +24,9 @@
 #include <X11/Xlib.h>
 #endif
 
-#include <glib-object.h>
 #include <gdk/gdk.h>
 #include <gio/gdesktopappinfo.h>
+#include <glib-object.h>
 
 // Support glib < 2.74, avoid deprecation warnings when building with xfce4-dev-tools >= 4.17.1
 
@@ -34,61 +34,65 @@
 #undef G_DEFINE_ENUM_TYPE
 #endif
 #define G_DEFINE_ENUM_TYPE(TypeName, type_name, ...) \
-GType \
-type_name ## _get_type (void) { \
-  static gsize g_define_type__static = 0; \
-  if (g_once_init_enter (&g_define_type__static)) { \
-    static const GEnumValue enum_values[] = { \
-      __VA_ARGS__ , \
-      { 0, NULL, NULL }, \
-    }; \
-    GType g_define_type = g_enum_register_static (g_intern_static_string (#TypeName), enum_values); \
-    g_once_init_leave (&g_define_type__static, g_define_type); \
-  } \
-  return g_define_type__static; \
-}
+    GType \
+        type_name##_get_type(void) { \
+        static gsize g_define_type__static = 0; \
+        if (g_once_init_enter(&g_define_type__static)) { \
+            static const GEnumValue enum_values[] = { \
+                __VA_ARGS__, \
+                { 0, NULL, NULL }, \
+            }; \
+            GType g_define_type = g_enum_register_static(g_intern_static_string(#TypeName), enum_values); \
+            g_once_init_leave(&g_define_type__static, g_define_type); \
+        } \
+        return g_define_type__static; \
+    }
 
 #ifdef G_DEFINE_FLAGS_TYPE
 #undef G_DEFINE_FLAGS_TYPE
 #endif
 #define G_DEFINE_FLAGS_TYPE(TypeName, type_name, ...) \
-GType \
-type_name ## _get_type (void) { \
-  static gsize g_define_type__static = 0; \
-  if (g_once_init_enter (&g_define_type__static)) { \
-    static const GFlagsValue flags_values[] = { \
-      __VA_ARGS__ , \
-      { 0, NULL, NULL }, \
-    }; \
-    GType g_define_type = g_flags_register_static (g_intern_static_string (#TypeName), flags_values); \
-    g_once_init_leave (&g_define_type__static, g_define_type); \
-  } \
-  return g_define_type__static; \
-}
+    GType \
+        type_name##_get_type(void) { \
+        static gsize g_define_type__static = 0; \
+        if (g_once_init_enter(&g_define_type__static)) { \
+            static const GFlagsValue flags_values[] = { \
+                __VA_ARGS__, \
+                { 0, NULL, NULL }, \
+            }; \
+            GType g_define_type = g_flags_register_static(g_intern_static_string(#TypeName), flags_values); \
+            g_once_init_leave(&g_define_type__static, g_define_type); \
+        } \
+        return g_define_type__static; \
+    }
 
 #ifdef G_DEFINE_ENUM_VALUE
 #undef G_DEFINE_ENUM_VALUE
 #endif
 #define G_DEFINE_ENUM_VALUE(EnumValue, EnumNick) \
-  { EnumValue, #EnumValue, EnumNick }
+    { \
+        EnumValue, #EnumValue, EnumNick \
+    }
 
 /* copied and adapted from g_warning_once (GLib 2.78) */
 #if defined(G_HAVE_ISO_VARARGS) && !G_ANALYZER_ANALYZING
 #define _xfw_g_message_once(...) \
-  G_STMT_START { \
-    static int G_PASTE (__XfwGMessageOnceBoolean, __LINE__) = 0;  /* (atomic) */ \
-    if (g_atomic_int_compare_and_exchange (&G_PASTE (__XfwGMessageOnceBoolean, __LINE__), \
-                                           0, 1)) \
-      g_message (__VA_ARGS__); \
-  } G_STMT_END
-#elif defined(G_HAVE_GNUC_VARARGS)  && !G_ANALYZER_ANALYZING
+    G_STMT_START { \
+        static int G_PASTE(__XfwGMessageOnceBoolean, __LINE__) = 0; /* (atomic) */ \
+        if (g_atomic_int_compare_and_exchange(&G_PASTE(__XfwGMessageOnceBoolean, __LINE__), \
+                                              0, 1)) \
+            g_message(__VA_ARGS__); \
+    } \
+    G_STMT_END
+#elif defined(G_HAVE_GNUC_VARARGS) && !G_ANALYZER_ANALYZING
 #define _xfw_g_message_once(format...) \
-  G_STMT_START { \
-    static int G_PASTE (__XfwGMessageOnceBoolean, __LINE__) = 0;  /* (atomic) */ \
-    if (g_atomic_int_compare_and_exchange (&G_PASTE (__XfwGMessageOnceBoolean, __LINE__), \
-                                           0, 1)) \
-      g_message (format); \
-  } G_STMT_END
+    G_STMT_START { \
+        static int G_PASTE(__XfwGMessageOnceBoolean, __LINE__) = 0; /* (atomic) */ \
+        if (g_atomic_int_compare_and_exchange(&G_PASTE(__XfwGMessageOnceBoolean, __LINE__), \
+                                              0, 1)) \
+            g_message(format); \
+    } \
+    G_STMT_END
 #else
 #define _xfw_g_message_once g_message
 #endif
@@ -97,13 +101,6 @@ G_BEGIN_DECLS
 
 typedef GdkPixbuf *(*XfwGetIconFunc)(GObject *wnck_object);
 
-enum {
-    SCREEN_PROP_SCREEN = 0x1000,
-    SCREEN_PROP_WORKSPACE_MANAGER,
-    SCREEN_PROP_ACTIVE_WINDOW,
-    SCREEN_PROP_SHOW_DESKTOP,
-};
-
 enum {
     WORKSPACE_MANAGER_PROP_SCREEN = 0x2000,
 };
@@ -124,6 +121,8 @@ enum {
     WORKSPACE_PROP_CAPABILITIES,
     WORKSPACE_PROP_STATE,
     WORKSPACE_PROP_NUMBER,
+    WORKSPACE_PROP_LAYOUT_ROW,
+    WORKSPACE_PROP_LAYOUT_COLUMN,
 };
 
 void _libxfce4windowing_init(void);
@@ -131,7 +130,6 @@ void _libxfce4windowing_init(void);
 GDesktopAppInfo *_xfw_g_desktop_app_info_get(const gchar *app_id);
 GdkPixbuf *_xfw_gicon_load(GIcon *gicon, gint size, gint scale);
 
-void _xfw_screen_install_properties(GObjectClass *gklass);
 void _xfw_workspace_manager_install_properties(GObjectClass *gklass);
 void _xfw_workspace_group_install_properties(GObjectClass *gklass);
 void _xfw_workspace_install_properties(GObjectClass *gklass);
@@ -147,4 +145,4 @@ GIcon *_xfw_wnck_object_get_gicon(GObject *wnck_object,
 
 G_END_DECLS
 
-#endif  /* __LIBXFCE4WINDOWING_PRIVATE_H__ */
+#endif /* __LIBXFCE4WINDOWING_PRIVATE_H__ */
