@@ -17,7 +17,9 @@
  * MA 02110-1301 USA
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include "libxfce4windowing-private.h"
 #include "xfw-application-private.h"
@@ -91,7 +93,8 @@ xfw_application_x11_init(XfwApplicationX11 *app) {
     app->priv = xfw_application_x11_get_instance_private(app);
 }
 
-static void xfw_application_x11_constructed(GObject *obj) {
+static void
+xfw_application_x11_constructed(GObject *obj) {
     XfwApplicationX11Private *priv = XFW_APPLICATION_X11(obj)->priv;
 
     g_hash_table_insert(wnck_groups, priv->wnck_group, obj);
@@ -200,7 +203,7 @@ icon_changed(WnckClassGroup *wnck_group, XfwApplicationX11 *app) {
 
 static void
 name_changed(WnckClassGroup *wnck_group, XfwApplicationX11 *app) {
-    GDesktopAppInfo *app_info = _xfw_g_desktop_app_info_get(wnck_class_group_get_name(wnck_group));
+    GDesktopAppInfo *app_info = _xfw_g_desktop_app_info_get(wnck_class_group_get_id(wnck_group));
     gchar *icon_name = NULL;
 
     if (app_info != NULL) {
@@ -217,7 +220,7 @@ name_changed(WnckClassGroup *wnck_group, XfwApplicationX11 *app) {
 }
 
 static gboolean
-find_instance (gpointer key, gpointer value, gpointer user_data) {
+find_instance(gpointer key, gpointer value, gpointer user_data) {
     return g_list_find(((XfwApplicationInstance *)value)->windows, user_data) != NULL;
 }
 
