@@ -33,6 +33,7 @@
 #include "xfw-wnck-icon.h"
 #include "xfw-workspace-x11.h"
 #include "xfw-x11.h"
+#include "libxfce4windowing-visibility.h"
 
 enum {
     PROP0,
@@ -67,7 +68,7 @@ static GdkRectangle *xfw_window_x11_get_geometry(XfwWindow *window);
 static XfwWorkspace *xfw_window_x11_get_workspace(XfwWindow *window);
 static GList *xfw_window_x11_get_monitors(XfwWindow *window);
 static XfwApplication *xfw_window_x11_get_application(XfwWindow *window);
-static gboolean xfw_window_x11_activate(XfwWindow *window, guint64 event_timestamp, GError **error);
+static gboolean xfw_window_x11_activate(XfwWindow *window, XfwSeat *seat, guint64 event_timestamp, GError **error);
 static gboolean xfw_window_x11_close(XfwWindow *window, guint64 event_timestamp, GError **error);
 static gboolean xfw_window_x11_start_move(XfwWindow *window, GError **error);
 static gboolean xfw_window_x11_start_resize(XfwWindow *window, GError **error);
@@ -181,7 +182,7 @@ xfw_window_x11_constructed(GObject *obj) {
     for (GList *l = xfw_screen_get_monitors(screen); l != NULL; l = l->next) {
         XfwMonitor *monitor = XFW_MONITOR(l->data);
         GdkRectangle geom;
-        xfw_monitor_get_logical_geometry(monitor, &geom);
+        xfw_monitor_get_physical_geometry(monitor, &geom);
         if (gdk_rectangle_intersect(&window->priv->geometry, &geom, NULL)) {
             window->priv->monitors = g_list_prepend(window->priv->monitors, monitor);
         }
@@ -308,7 +309,7 @@ xfw_window_x11_get_application(XfwWindow *window) {
 }
 
 static gboolean
-xfw_window_x11_activate(XfwWindow *window, guint64 event_timestamp, GError **error) {
+xfw_window_x11_activate(XfwWindow *window, XfwSeat *seat, guint64 event_timestamp, GError **error) {
     XfwWindowX11Private *priv = XFW_WINDOW_X11(window)->priv;
     wnck_window_activate(priv->wnck_window, (guint32)event_timestamp);
     return TRUE;
@@ -657,7 +658,7 @@ geometry_changed(WnckWindow *wnck_window, XfwWindowX11 *window) {
     for (GList *lp = window->priv->monitors; lp != NULL;) {
         GList *lnext = lp->next;
         GdkRectangle geom;
-        xfw_monitor_get_logical_geometry(XFW_MONITOR(lp->data), &geom);
+        xfw_monitor_get_physical_geometry(XFW_MONITOR(lp->data), &geom);
         if (!gdk_rectangle_intersect(&window->priv->geometry, &geom, NULL)) {
             window->priv->monitors = g_list_delete_link(window->priv->monitors, lp);
             notify = TRUE;
@@ -668,7 +669,7 @@ geometry_changed(WnckWindow *wnck_window, XfwWindowX11 *window) {
     for (GList *l = xfw_screen_get_monitors(_xfw_window_get_screen(XFW_WINDOW(window))); l != NULL; l = l->next) {
         XfwMonitor *monitor = XFW_MONITOR(l->data);
         GdkRectangle geom;
-        xfw_monitor_get_logical_geometry(monitor, &geom);
+        xfw_monitor_get_physical_geometry(monitor, &geom);
         if (gdk_rectangle_intersect(&window->priv->geometry, &geom, NULL) && !g_list_find(window->priv->monitors, monitor)) {
             window->priv->monitors = g_list_prepend(window->priv->monitors, monitor);
             notify = TRUE;
@@ -683,7 +684,7 @@ geometry_changed(WnckWindow *wnck_window, XfwWindowX11 *window) {
 static void
 monitor_added(XfwScreen *screen, XfwMonitor *monitor, XfwWindowX11 *window) {
     GdkRectangle geom;
-    xfw_monitor_get_logical_geometry(monitor, &geom);
+    xfw_monitor_get_physical_geometry(monitor, &geom);
     if (gdk_rectangle_intersect(&window->priv->geometry, &geom, NULL)) {
         window->priv->monitors = g_list_prepend(window->priv->monitors, monitor);
         g_object_notify(G_OBJECT(window), "monitors");
@@ -843,3 +844,6 @@ WnckWindow *
 _xfw_window_x11_get_wnck_window(XfwWindowX11 *window) {
     return window->priv->wnck_window;
 }
+
+#define __XFW_WINDOW_X11_C__
+#include <libxfce4windowing-visibility.c>
