@@ -17,11 +17,13 @@
  * MA 02110-1301 USA
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <limits.h>
 
-#include "protocols/ext-workspace-v1-20230427-client.h"
+#include "protocols/ext-workspace-v1-client.h"
 
 #include "libxfce4windowing-private.h"
 #include "xfw-util.h"
@@ -33,11 +35,14 @@
 struct _XfwWorkspaceWaylandPrivate {
     XfwWorkspaceGroup *group;
     struct ext_workspace_handle_v1 *handle;
+    struct ext_workspace_manager_v1 *manager_handle;
     gchar *id;
     gchar *name;
     XfwWorkspaceCapabilities capabilities;
     XfwWorkspaceState state;
     guint number;
+    gint row;
+    gint column;
     GdkRectangle geometry;
 };
 
@@ -52,7 +57,7 @@ enum {
     PROP_HANDLE,
 };
 
-static guint workspace_signals[N_SIGNALS] = { 0, };
+static guint workspace_signals[N_SIGNALS] = { 0 };
 
 static void xfw_workspace_wayland_workspace_init(XfwWorkspaceIface *iface);
 static void xfw_workspace_wayland_constructed(GObject *obj);
@@ -73,6 +78,7 @@ static gboolean xfw_workspace_wayland_activate(XfwWorkspace *workspace, GError *
 static gboolean xfw_workspace_wayland_remove(XfwWorkspace *workspace, GError **error);
 static gboolean xfw_workspace_wayland_assign_to_workspace_group(XfwWorkspace *workspace, XfwWorkspaceGroup *group, GError **error);
 
+static void workspace_id(void *data, struct ext_workspace_handle_v1 *workspace, const char *id);
 static void workspace_name(void *data, struct ext_workspace_handle_v1 *workspace, const char *name);
 static void workspace_coordinates(void *data, struct ext_workspace_handle_v1 *workspace, struct wl_array *coordinates);
 static void workspace_state(void *data, struct ext_workspace_handle_v1 *workspace, uint32_t state);
@@ -80,6 +86,7 @@ static void workspace_capabilities(void *data, struct ext_workspace_handle_v1 *w
 static void workspace_removed(void *data, struct ext_workspace_handle_v1 *workspace);
 
 static const struct ext_workspace_handle_v1_listener workspace_listener = {
+    .id = workspace_id,
     .name = workspace_name,
     .coordinates = workspace_coordinates,
     .state = workspace_state,
@@ -120,12 +127,13 @@ xfw_workspace_wayland_class_init(XfwWorkspaceWaylandClass *klass) {
 static void
 xfw_workspace_wayland_init(XfwWorkspaceWayland *workspace) {
     workspace->priv = xfw_workspace_wayland_get_instance_private(workspace);
+    workspace->priv->row = -1;
+    workspace->priv->column = -1;
 }
 
 static void
 xfw_workspace_wayland_constructed(GObject *obj) {
     XfwWorkspaceWayland *workspace = XFW_WORKSPACE_WAYLAND(obj);
-    workspace->priv->id = g_strdup_printf("%u", wl_proxy_get_id((struct wl_proxy *)workspace->priv->handle));
     ext_workspace_handle_v1_add_listener(workspace->priv->handle, &workspace_listener, workspace);
 }
 
@@ -156,7 +164,13 @@ xfw_workspace_wayland_set_property(GObject *obj, guint prop_id, const GValue *va
 
         case WORKSPACE_PROP_GROUP:
         case WORKSPACE_PROP_ID:
+            g_free(workspace->priv->id);
+            workspace->priv->id = g_value_dup_string(value);
+            break;
         case WORKSPACE_PROP_NAME:
+            g_free(workspace->priv->name);
+            workspace->priv->name = g_value_dup_string(value);
+            break;
         case WORKSPACE_PROP_CAPABILITIES:
         case WORKSPACE_PROP_STATE:
         case WORKSPACE_PROP_NUMBER:
@@ -181,7 +195,7 @@ xfw_workspace_wayland_get_property(GObject *obj, guint prop_id, GValue *value, G
             break;
 
         case WORKSPACE_PROP_ID:
-            g_value_set_string(value, workspace->priv->name);
+            g_value_set_string(value, workspace->priv->id);
             break;
 
         case WORKSPACE_PROP_NAME:
@@ -196,6 +210,14 @@ xfw_workspace_wayland_get_property(GObject *obj, guint prop_id, GValue *value, G
             g_value_set_flags(value, workspace->priv->state);
             break;
 
+        case WORKSPACE_PROP_LAYOUT_ROW:
+            g_value_set_int(value, workspace->priv->row);
+            break;
+
+        case WORKSPACE_PROP_LAYOUT_COLUMN:
+            g_value_set_int(value, workspace->priv->column);
+            break;
+
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, prop_id, pspec);
             break;
@@ -245,16 +267,20 @@ xfw_workspace_wayland_get_workspace_group(XfwWorkspace *workspace) {
 
 static gint
 xfw_workspace_wayland_get_layout_row(XfwWorkspace *workspace) {
-    return 0;
+    XfwWorkspaceWayland *wworkspace = XFW_WORKSPACE_WAYLAND(workspace);
+    return wworkspace->priv->row >= 0 ? wworkspace->priv->row : 0;
 }
 
 static gint
 xfw_workspace_wayland_get_layout_column(XfwWorkspace *workspace) {
-    return xfw_workspace_wayland_get_number(workspace);
+    XfwWorkspaceWayland *wworkspace = XFW_WORKSPACE_WAYLAND(workspace);
+    return wworkspace->priv->column >= 0 ? wworkspace->priv->column : (gint)wworkspace->priv->number;
 }
 
 static XfwWorkspace *
 xfw_workspace_wayland_get_neighbor(XfwWorkspace *workspace, XfwDirection direction) {
+    XfwWorkspaceWayland *wworkspace = XFW_WORKSPACE_WAYLAND(workspace);
+
     switch (direction) {
         case XFW_DIRECTION_UP:
         case XFW_DIRECTION_DOWN:
@@ -262,18 +288,22 @@ xfw_workspace_wayland_get_neighbor(XfwWorkspace *workspace, XfwDirection directi
 
         case XFW_DIRECTION_LEFT: {
             gint num = xfw_workspace_wayland_get_layout_column(workspace);
-            if (num < 1) {
+            if (wworkspace->priv->group == NULL || num < 1) {
                 return NULL;
             } else {
-                GList *workspaces = xfw_workspace_group_list_workspaces(XFW_WORKSPACE_WAYLAND(workspace)->priv->group);
+                GList *workspaces = xfw_workspace_group_list_workspaces(wworkspace->priv->group);
                 return XFW_WORKSPACE(g_list_nth_data(workspaces, num - 1));
             }
         }
 
         case XFW_DIRECTION_RIGHT: {
-            gint num = xfw_workspace_wayland_get_layout_column(workspace);
-            GList *workspaces = xfw_workspace_group_list_workspaces(XFW_WORKSPACE_WAYLAND(workspace)->priv->group);
-            return XFW_WORKSPACE(g_list_nth_data(workspaces, num + 1));
+            if (wworkspace->priv->group == NULL) {
+                return NULL;
+            } else {
+                gint num = xfw_workspace_wayland_get_layout_column(workspace);
+                GList *workspaces = xfw_workspace_group_list_workspaces(wworkspace->priv->group);
+                return XFW_WORKSPACE(g_list_nth_data(workspaces, num + 1));
+            }
         }
     }
 
@@ -293,6 +323,7 @@ xfw_workspace_wayland_activate(XfwWorkspace *workspace, GError **error) {
 
     if ((wworkspace->priv->capabilities & XFW_WORKSPACE_CAPABILITIES_ACTIVATE) != 0) {
         ext_workspace_handle_v1_activate(XFW_WORKSPACE_WAYLAND(workspace)->priv->handle);
+        ext_workspace_manager_v1_commit(wworkspace->priv->manager_handle);
         return TRUE;
     } else {
         if (error != NULL) {
@@ -308,6 +339,7 @@ xfw_workspace_wayland_remove(XfwWorkspace *workspace, GError **error) {
 
     if ((wworkspace->priv->capabilities & XFW_WORKSPACE_CAPABILITIES_REMOVE) != 0) {
         ext_workspace_handle_v1_remove(XFW_WORKSPACE_WAYLAND(workspace)->priv->handle);
+        ext_workspace_manager_v1_commit(wworkspace->priv->manager_handle);
         return TRUE;
     } else {
         if (error != NULL) {
@@ -324,6 +356,7 @@ xfw_workspace_wayland_assign_to_workspace_group(XfwWorkspace *workspace, XfwWork
     if ((wworkspace->priv->capabilities & XFW_WORKSPACE_CAPABILITIES_ASSIGN) != 0) {
         ext_workspace_handle_v1_assign(XFW_WORKSPACE_WAYLAND(workspace)->priv->handle,
                                        _xfw_workspace_group_wayland_get_handle(XFW_WORKSPACE_GROUP_WAYLAND(group)));
+        ext_workspace_manager_v1_commit(wworkspace->priv->manager_handle);
         return TRUE;
     } else {
         if (error != NULL) {
@@ -333,6 +366,12 @@ xfw_workspace_wayland_assign_to_workspace_group(XfwWorkspace *workspace, XfwWork
     }
 }
 
+static void
+workspace_id(void *data, struct ext_workspace_handle_v1 *wl_workspace, const char *id) {
+    XfwWorkspaceWayland *workspace = XFW_WORKSPACE_WAYLAND(data);
+    g_object_set(workspace, "id", id, NULL);
+}
+
 static void
 workspace_name(void *data, struct ext_workspace_handle_v1 *wl_workspace, const char *name) {
     XfwWorkspaceWayland *workspace = XFW_WORKSPACE_WAYLAND(data);
@@ -341,8 +380,23 @@ workspace_name(void *data, struct ext_workspace_handle_v1 *wl_workspace, const c
 }
 
 static void
-workspace_coordinates(void *data, struct ext_workspace_handle_v1 *workspace, struct wl_array *coordinates) {
+workspace_coordinates(void *data, struct ext_workspace_handle_v1 *wl_workspace, struct wl_array *coordinates) {
+    XfwWorkspaceWayland *workspace = XFW_WORKSPACE_WAYLAND(data);
 
+    uint32_t *array_start = coordinates->data;
+
+    g_object_freeze_notify(G_OBJECT(workspace));
+
+    if (coordinates->size >= 1 && (int32_t)array_start[0] != workspace->priv->row) {
+        workspace->priv->row = array_start[0];
+        g_object_notify(G_OBJECT(workspace), "layout-row");
+    }
+    if (coordinates->size >= 2 && (int32_t)array_start[1] != workspace->priv->column) {
+        workspace->priv->column = array_start[1];
+        g_object_notify(G_OBJECT(workspace), "layout-column");
+    }
+
+    g_object_thaw_notify(G_OBJECT(workspace));
 }
 
 static const struct {
@@ -372,7 +426,7 @@ workspace_state(void *data, struct ext_workspace_handle_v1 *wl_workspace, uint32
     changed_mask = old_state ^ new_state;
     g_object_notify(G_OBJECT(workspace), "state");
     g_signal_emit_by_name(workspace, "state-changed", changed_mask, new_state);
-    if ((changed_mask & XFW_WORKSPACE_STATE_ACTIVE) != 0) {
+    if (workspace->priv->group != NULL && (changed_mask & XFW_WORKSPACE_STATE_ACTIVE) != 0) {
         if ((new_state & XFW_WORKSPACE_STATE_ACTIVE) != 0) {
             _xfw_workspace_group_wayland_set_active_workspace(XFW_WORKSPACE_GROUP_WAYLAND(workspace->priv->group), XFW_WORKSPACE(workspace));
         } else {
@@ -387,13 +441,13 @@ workspace_state(void *data, struct ext_workspace_handle_v1 *wl_workspace, uint32
 }
 
 static const struct {
-    enum ext_workspace_handle_v1_ext_workspace_capabilities_v1 wl_capability;
+    enum ext_workspace_handle_v1_workspace_capabilities wl_capability;
     XfwWorkspaceCapabilities capability_bit;
 } capabilities_converters[] = {
-    { EXT_WORKSPACE_HANDLE_V1_EXT_WORKSPACE_CAPABILITIES_V1_ACTIVATE, XFW_WORKSPACE_CAPABILITIES_ACTIVATE },
-    { EXT_WORKSPACE_HANDLE_V1_EXT_WORKSPACE_CAPABILITIES_V1_DEACTIVATE, XFW_WORKSPACE_CAPABILITIES_DEACTIVATE },
-    { EXT_WORKSPACE_HANDLE_V1_EXT_WORKSPACE_CAPABILITIES_V1_REMOVE, XFW_WORKSPACE_CAPABILITIES_REMOVE },
-    { EXT_WORKSPACE_HANDLE_V1_EXT_WORKSPACE_CAPABILITIES_V1_ASSIGN, XFW_WORKSPACE_CAPABILITIES_ASSIGN },
+    { EXT_WORKSPACE_HANDLE_V1_WORKSPACE_CAPABILITIES_ACTIVATE, XFW_WORKSPACE_CAPABILITIES_ACTIVATE },
+    { EXT_WORKSPACE_HANDLE_V1_WORKSPACE_CAPABILITIES_DEACTIVATE, XFW_WORKSPACE_CAPABILITIES_DEACTIVATE },
+    { EXT_WORKSPACE_HANDLE_V1_WORKSPACE_CAPABILITIES_REMOVE, XFW_WORKSPACE_CAPABILITIES_REMOVE },
+    { EXT_WORKSPACE_HANDLE_V1_WORKSPACE_CAPABILITIES_ASSIGN, XFW_WORKSPACE_CAPABILITIES_ASSIGN },
 };
 
 static void
@@ -440,6 +494,16 @@ _xfw_workspace_wayland_set_workspace_group(XfwWorkspaceWayland *workspace, XfwWo
     if (group != workspace->priv->group) {
         XfwWorkspaceGroup *previous_group = workspace->priv->group;
         workspace->priv->group = group;
+        // ensure active workspace is initialized, since workspace state can be sent before
+        // workspace enters the group
+        if ((workspace->priv->state & XFW_WORKSPACE_STATE_ACTIVE) != 0) {
+            _xfw_workspace_group_wayland_set_active_workspace(XFW_WORKSPACE_GROUP_WAYLAND(group), XFW_WORKSPACE(workspace));
+        }
         g_signal_emit_by_name(workspace, "group-changed", previous_group);
     }
 }
+
+void
+_xfw_workspace_wayland_set_workspace_manager_handle(XfwWorkspaceWayland *workspace, struct ext_workspace_manager_v1 *manager_handle) {
+    workspace->priv->manager_handle = manager_handle;
+}
