@@ -25,19 +25,18 @@
 #endif
 
 #include <glib-object.h>
-
-#include "xfw-util.h"
+#include <libxfce4windowing/xfw-util.h>
 
 G_BEGIN_DECLS
 
 /* fwd decl */
-typedef struct _XfwWorkspaceGroup XfwWorkspaceGroup;
+struct _XfwWorkspaceGroup;
 
 #define XFW_TYPE_WORKSPACE (xfw_workspace_get_type())
 G_DECLARE_INTERFACE(XfwWorkspace, xfw_workspace, XFW, WORKSPACE, GObject)
 
 #define XFW_TYPE_WORKSPACE_CAPABILITIES (xfw_workspace_capabilities_get_type())
-#define XFW_TYPE_WORKSPACE_STATE        (xfw_workspace_state_get_type())
+#define XFW_TYPE_WORKSPACE_STATE (xfw_workspace_state_get_type())
 
 typedef struct _XfwWorkspaceInterface XfwWorkspaceIface;
 
@@ -88,7 +87,7 @@ const gchar *xfw_workspace_get_name(XfwWorkspace *workspace);
 XfwWorkspaceCapabilities xfw_workspace_get_capabilities(XfwWorkspace *workspace);
 XfwWorkspaceState xfw_workspace_get_state(XfwWorkspace *workspace);
 guint xfw_workspace_get_number(XfwWorkspace *workspace);
-XfwWorkspaceGroup *xfw_workspace_get_workspace_group(XfwWorkspace *workspace);
+struct _XfwWorkspaceGroup *xfw_workspace_get_workspace_group(XfwWorkspace *workspace);
 
 gint xfw_workspace_get_layout_row(XfwWorkspace *workspace);
 gint xfw_workspace_get_layout_column(XfwWorkspace *workspace);
@@ -98,8 +97,8 @@ GdkRectangle *xfw_workspace_get_geometry(XfwWorkspace *workspace);
 gboolean xfw_workspace_activate(XfwWorkspace *workspace, GError **error);
 gboolean xfw_workspace_remove(XfwWorkspace *workspace, GError **error);
 
-gboolean xfw_workspace_assign_to_workspace_group(XfwWorkspace *workspace, XfwWorkspaceGroup *group, GError **error);
+gboolean xfw_workspace_assign_to_workspace_group(XfwWorkspace *workspace, struct _XfwWorkspaceGroup *group, GError **error);
 
 G_END_DECLS
 
-#endif  /* !__XFW_WORKSPACE_H__ */
+#endif /* !__XFW_WORKSPACE_H__ */
